Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(174)

Unified Diff: webrtc/media/engine/webrtcvideoengine.h

Issue 2932073002: s/WebRtcVideoChannel2/WebRtcVideoChannel and s/WebRtcVideoEngine2/WebRtcVideoEngine (Closed)
Patch Set: . Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/media/engine/webrtcmediaengine.cc ('k') | webrtc/media/engine/webrtcvideoengine.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/media/engine/webrtcvideoengine.h
diff --git a/webrtc/media/engine/webrtcvideoengine2.h b/webrtc/media/engine/webrtcvideoengine.h
similarity index 94%
copy from webrtc/media/engine/webrtcvideoengine2.h
copy to webrtc/media/engine/webrtcvideoengine.h
index 56431167a8397f06b4f1c70de3df8cfd06d18231..29c44cecf40a3855e339c340148626509d6237a8 100644
--- a/webrtc/media/engine/webrtcvideoengine2.h
+++ b/webrtc/media/engine/webrtcvideoengine.h
@@ -8,8 +8,8 @@
* be found in the AUTHORS file in the root of the source tree.
*/
-#ifndef WEBRTC_MEDIA_ENGINE_WEBRTCVIDEOENGINE2_H_
-#define WEBRTC_MEDIA_ENGINE_WEBRTCVIDEOENGINE2_H_
+#ifndef WEBRTC_MEDIA_ENGINE_WEBRTCVIDEOENGINE_H_
+#define WEBRTC_MEDIA_ENGINE_WEBRTCVIDEOENGINE_H_
#include <map>
#include <memory>
@@ -55,7 +55,7 @@ class WebRtcDecoderObserver;
class WebRtcEncoderObserver;
class WebRtcLocalStreamInfo;
class WebRtcRenderAdapter;
-class WebRtcVideoChannel2;
+class WebRtcVideoChannel;
class WebRtcVideoChannelRecvInfo;
class WebRtcVideoChannelSendInfo;
class WebRtcVoiceEngine;
@@ -69,7 +69,7 @@ class UnsignalledSsrcHandler {
kDropPacket,
kDeliverPacket,
};
- virtual Action OnUnsignalledSsrc(WebRtcVideoChannel2* channel,
+ virtual Action OnUnsignalledSsrc(WebRtcVideoChannel* channel,
uint32_t ssrc) = 0;
virtual ~UnsignalledSsrcHandler() = default;
};
@@ -78,11 +78,11 @@ class UnsignalledSsrcHandler {
class DefaultUnsignalledSsrcHandler : public UnsignalledSsrcHandler {
public:
DefaultUnsignalledSsrcHandler();
- Action OnUnsignalledSsrc(WebRtcVideoChannel2* channel,
+ Action OnUnsignalledSsrc(WebRtcVideoChannel* channel,
uint32_t ssrc) override;
rtc::VideoSinkInterface<webrtc::VideoFrame>* GetDefaultSink() const;
- void SetDefaultSink(WebRtcVideoChannel2* channel,
+ void SetDefaultSink(WebRtcVideoChannel* channel,
rtc::VideoSinkInterface<webrtc::VideoFrame>* sink);
virtual ~DefaultUnsignalledSsrcHandler() = default;
@@ -91,18 +91,18 @@ class DefaultUnsignalledSsrcHandler : public UnsignalledSsrcHandler {
rtc::VideoSinkInterface<webrtc::VideoFrame>* default_sink_;
};
-// WebRtcVideoEngine2 is used for the new native WebRTC Video API (webrtc:1667).
-class WebRtcVideoEngine2 {
+// WebRtcVideoEngine is used for the new native WebRTC Video API (webrtc:1667).
+class WebRtcVideoEngine {
public:
- WebRtcVideoEngine2();
- virtual ~WebRtcVideoEngine2();
+ WebRtcVideoEngine();
+ virtual ~WebRtcVideoEngine();
// Basic video engine implementation.
void Init();
- WebRtcVideoChannel2* CreateChannel(webrtc::Call* call,
- const MediaConfig& config,
- const VideoOptions& options);
+ WebRtcVideoChannel* CreateChannel(webrtc::Call* call,
+ const MediaConfig& config,
+ const VideoOptions& options);
std::vector<VideoCodec> codecs() const;
RtpCapabilities GetCapabilities() const;
@@ -125,14 +125,14 @@ class WebRtcVideoEngine2 {
std::unique_ptr<WebRtcVideoEncoderFactory> simulcast_encoder_factory_;
};
-class WebRtcVideoChannel2 : public VideoMediaChannel, public webrtc::Transport {
+class WebRtcVideoChannel : public VideoMediaChannel, public webrtc::Transport {
public:
- WebRtcVideoChannel2(webrtc::Call* call,
- const MediaConfig& config,
- const VideoOptions& options,
- WebRtcVideoEncoderFactory* external_encoder_factory,
- WebRtcVideoDecoderFactory* external_decoder_factory);
- ~WebRtcVideoChannel2() override;
+ WebRtcVideoChannel(webrtc::Call* call,
+ const MediaConfig& config,
+ const VideoOptions& options,
+ WebRtcVideoEncoderFactory* external_encoder_factory,
+ WebRtcVideoDecoderFactory* external_decoder_factory);
+ ~WebRtcVideoChannel() override;
// VideoMediaChannel implementation
rtc::DiffServCodePoint PreferredDscp() const override;
@@ -459,7 +459,7 @@ class WebRtcVideoChannel2 : public VideoMediaChannel, public webrtc::Transport {
int64_t estimated_remote_start_ntp_time_ms_ GUARDED_BY(sink_lock_);
};
- void Construct(webrtc::Call* call, WebRtcVideoEngine2* engine);
+ void Construct(webrtc::Call* call, WebRtcVideoEngine* engine);
bool SendRtp(const uint8_t* data,
size_t len,
@@ -512,7 +512,7 @@ class WebRtcVideoChannel2 : public VideoMediaChannel, public webrtc::Transport {
std::vector<VideoCodecSettings> recv_codecs_;
std::vector<webrtc::RtpExtension> recv_rtp_extensions_;
// See reason for keeping track of the FlexFEC payload type separately in
- // comment in WebRtcVideoChannel2::ChangedRecvParameters.
+ // comment in WebRtcVideoChannel::ChangedRecvParameters.
int recv_flexfec_payload_type_;
webrtc::Call::Config::BitrateConfig bitrate_config_;
// TODO(deadbeef): Don't duplicate information between
@@ -525,4 +525,4 @@ class WebRtcVideoChannel2 : public VideoMediaChannel, public webrtc::Transport {
} // namespace cricket
-#endif // WEBRTC_MEDIA_ENGINE_WEBRTCVIDEOENGINE2_H_
+#endif // WEBRTC_MEDIA_ENGINE_WEBRTCVIDEOENGINE_H_
« no previous file with comments | « webrtc/media/engine/webrtcmediaengine.cc ('k') | webrtc/media/engine/webrtcvideoengine.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698